==> kubernetes-client_3-0.11.0-sources.jar: CSIStorageCapacityList.scala <==
package io.k8s.api.storage.v1beta1

import io.circe.*
import io.circe.generic.semiauto.*

/** CSIStorageCapacityList is a collection of CSIStorageCapacity objects.
 *
 *  @param      items  Items is the list of CSIStorageCapacity objects.
 *  @param apiVersion  APIVersion defines the versioned schema of this representation of an object. Servers should convert
 *                     recognized schemas to the latest internal value, and may reject unrecognized values. More info:
 *                     https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
 *  @param       kind  Kind is a string value representing the REST resource this object represents. Servers may infer this
 *                     from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info:
 *                     https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
 *  @param   metadata  Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
*/
case class CSIStorageCapacityList(
  items: Seq[io.k8s.api.storage.v1beta1.CSIStorageCapacity],
  apiVersion: Option[String] = None,
  kind: Option[String] = None,
  metadata: Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
)

object CSIStorageCapacityList {
  implicit lazy val encoder: Encoder.AsObject[CSIStorageCapacityList] = deriveEncoder
  implicit lazy val decoder: Decoder[CSIStorageCapacityList] = deriveDecoder
}

==> kubernetes-client_3-0.11.1-sources.jar: CSIStorageCapacityList.scala <==
package io.k8s.api.storage.v1

import io.circe.*
import io.circe.generic.semiauto.*

/** CSIStorageCapacityList is a collection of CSIStorageCapacity objects.
 *
 *  @param      items  items is the list of CSIStorageCapacity objects.
 *  @param apiVersion  APIVersion defines the versioned schema of this representation of an object. Servers should convert
 *                     recognized schemas to the latest internal value, and may reject unrecognized values. More info:
 *                     https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources
 *  @param       kind  Kind is a string value representing the REST resource this object represents. Servers may infer this
 *                     from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info:
 *                     https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds
 *  @param   metadata  Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata
*/
case class CSIStorageCapacityList(
  items: Seq[io.k8s.api.storage.v1.CSIStorageCapacity],
  apiVersion: Option[String] = None,
  kind: Option[String] = None,
  metadata: Option[io.k8s.apimachinery.pkg.apis.meta.v1.ListMeta] = None
)

object CSIStorageCapacityList {
  implicit lazy val encoder: Encoder.AsObject[CSIStorageCapacityList] = deriveEncoder
  implicit lazy val decoder: Decoder[CSIStorageCapacityList] = deriveDecoder
}
